@@ -212,30 +212,6 @@ get_estimates_parameters <- function(model,
         if (!"diagnostic" %in% names(dots)) args <- c(args, list("diagnostic" = NULL))
     }
 
-    # mixed-effects: ci_random can be very slow in some models in parameters<=0.18.1
-    fmi <- isTRUE(mi[["is_mixed"]])
-    fci <- isTRUE(conf_int)
-    fra <- !"ci_random" %in% names(args)
-    fve <- utils::packageVersion("parameters") <= "0.18.1"
-    if (fmi && fci && fra && fve) {
-        msg <- format_msg(
-        'Computing confidence intervals for mixed-effects models requires installing a
-        version of the {parameters} package greater than 0.18.1. This version may be
-        available on CRAN:
-
-        install.packages("parameters")
-
-        If {parameters} 0.18.2 is not yet available on CRAN, you can install the
-        development version:
-
-        library(remotes)
-        install_github("easystats/parameters") 
-
-        Make sure you restart R after updating.
-        ')
-        stop(msg, call. = FALSE)
-    }
-
     # main call
     fun <- tidy_easystats <- function(x, ...) {
         out <- parameters::parameters(x, ...)
